@@ -62,13 +62,13 @@ class AmocrmRunner:
 
     def __init__(
             self,
-            action,
-            etl_name_no_version,
-            execution_date,
-            config_name,
-            entity,
-            args_s3,
-            sql_credentials,
+            action=None,
+            etl_name_no_version=None,
+            execution_date=None,
+            config_name=None,
+            entity=None,
+            args_s3=None,
+            sql_credentials=None,
             hours_to_modify=1,
             db=None,
             table_name=None,
